@@ -1,10 +1,12 @@
+from __future__ import absolute_import
 import copy
 import time
 from datetime import datetime, timedelta
 from cqlengine import BaseContainerColumn, Map, columns
 from cqlengine.columns import Counter, List, Set
 
-from cqlengine.connection import execute
+from .connection import execute, NOT_SET
+
 from cqlengine.exceptions import CQLEngineException, ValidationError, LWTException
 from cqlengine.functions import Token, BaseQueryFunction, QueryValue, UnicodeMixin
 
@@ -87,7 +89,8 @@ class BatchQuery(object):
     """
     _consistency = None
 
-    def __init__(self, batch_type=None, timestamp=None, consistency=None, execute_on_exception=False):
+    def __init__(self, batch_type=None, timestamp=None, consistency=None, execute_on_exception=False,
+                 timeout=NOT_SET):
         """
         :param batch_type: (optional) One of batch type values available through BatchType enum
         :type batch_type: str or None
@@ -101,10 +104,9 @@ class BatchQuery(object):
             encountering an error within the context. By default, any exception raised from within
             the context scope will cause the batched queries not to be executed.
         :type execute_on_exception: bool
-        :param callbacks: A list of functions to be executed after the batch executes. Note, that if the batch
-            does not execute, the callbacks are not executed. This, thus, effectively is a list of "on success"
-            callback handlers. If defined, must be a collection of callables.
-        :type callbacks: list or set or tuple
+        :param timeout: (optional) Timeout for the entire batch (in seconds), if not specified fallback
+            to default session timeout
+        :type timeout: float or None
         """
         self.queries = []
         self.batch_type = batch_type
@@ -113,6 +115,7 @@ class BatchQuery(object):
         self.timestamp = timestamp
         self._consistency = consistency
         self._execute_on_exception = execute_on_exception
+        self._timeout = timeout
         self._callbacks = []
 
     def add_query(self, query):
@@ -181,7 +184,7 @@ class BatchQuery(object):
 
         query_list.append('APPLY BATCH;')
 
-        tmp = execute('\n'.join(query_list), parameters, self._consistency)
+        tmp = execute('\n'.join(query_list), parameters, self._consistency, self._timeout)
         check_applied(tmp)
 
         self.queries = []
@@ -235,6 +238,7 @@ class AbstractQuerySet(object):
         self._consistency = None
         self._timestamp = None
         self._if_not_exists = False
+        self._timeout = NOT_SET
 
     @property
     def column_family_name(self):
@@ -244,7 +248,7 @@ class AbstractQuerySet(object):
         if self._batch:
             return self._batch.add_query(q)
         else:
-            result = execute(q, consistency_level=self._consistency)
+            result = execute(q, consistency_level=self._consistency, timeout=self._timeout)
             if self._transaction:
                 check_applied(result)
             return result
@@ -269,6 +273,8 @@ class AbstractQuerySet(object):
                 # fly off into other batch instances which are never
                 # executed, thx @dokai
                 clone.__dict__[k] = self._batch
+            elif k == '_timeout':
+                clone.__dict__[k] = self._timeout
             else:
                 clone.__dict__[k] = copy.deepcopy(v, memo)
 
@@ -656,6 +662,15 @@ class AbstractQuerySet(object):
     def __ne__(self, q):
         return not (self != q)
 
+    def timeout(self, timeout):
+        """
+        :param timeout: Timeout for the query (in seconds)
+        :type timeout: float or None
+        """
+        clone = copy.deepcopy(self)
+        clone._timeout = timeout
+        return clone
+
 
 class ResultObject(dict):
     """
@@ -835,7 +850,8 @@ class DMLQuery(object):
     _timestamp = None
     _if_not_exists = False
 
-    def __init__(self, model, instance=None, batch=None, ttl=None, consistency=None, timestamp=None, if_not_exists=False, transaction=None):
+    def __init__(self, model, instance=None, batch=None, ttl=None, consistency=None, timestamp=None,
+                 if_not_exists=False, transaction=None, timeout=NOT_SET):
         self.model = model
         self.column_family_name = self.model.column_family_name()
         self.instance = instance
@@ -845,12 +861,13 @@ class DMLQuery(object):
         self._timestamp = timestamp
         self._if_not_exists = if_not_exists
         self._transaction = transaction
+        self._timeout = timeout
 
     def _execute(self, q):
         if self._batch:
             return self._batch.add_query(q)
         else:
-            tmp = execute(q, consistency_level=self._consistency)
+            tmp = execute(q, consistency_level=self._consistency, timeout=self._timeout)
             if self._if_not_exists or self._transaction:
                 check_applied(tmp)
             return tmp
@@ -994,5 +1011,3 @@ class DMLQuery(object):
                 col.to_database(getattr(self.instance, name))
             ))
         self._execute(ds)
-
-
